pub trait InputEventsImpl {
// Required methods
fn get_read_notify_fd(&self) -> Result<BorrowedFd<'_>, InputBackendError>;
fn next_event(&mut self) -> Result<Option<InputEvent>, InputBackendError>;
}Required Methods
Sourcefn get_read_notify_fd(&self) -> Result<BorrowedFd<'_>, InputBackendError>
fn get_read_notify_fd(&self) -> Result<BorrowedFd<'_>, InputBackendError>
Get the file descriptor that becomes ready when input events are available
Sourcefn next_event(&mut self) -> Result<Option<InputEvent>, InputBackendError>
fn next_event(&mut self) -> Result<Option<InputEvent>, InputBackendError>
Fetch the next available input event, returns None if no events are available
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".